.. bte documentation master file, created by
   sphinx-quickstart on Sat Apr 23 16:29:04 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to bte's documentation!
===============================

.. toctree::
   :maxdepth: 3

   usage

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
